@@ -27,8 +27,6 @@ def sphinx_gallery_find_example_and_build_dirs(source: str, dest: str) -> Tuple[
     examples_pairs = [(e, ae) for e, ae in zip(examples_paths, auto_examples_paths) if e.exists() and e.is_dir()]
     for example, auto_example in examples_pairs:
         auto_example.mkdir(parents=True, exist_ok=True)
-        for support_file in [file for file in example.glob(f'_*') if file.is_file()]:
-            shutil.copy(support_file, auto_example)
 
     examples = tuple(map(list, zip(*[[str(e.resolve()), str(ae.resolve())] for e, ae in examples_pairs])))
     return cast(Tuple[List[str], List[str]], examples if len(examples) == 2 else ([], []))
